<?php

namespace drp\AdminPanel\User;

use Auth;
use Illuminate\Support\ServiceProvider;

class UserServiceProvider extends ServiceProvider
{
    /**
     * Perform post-registration booting of services.
     *
     * @return void
     */
    public function boot()
    {
        $this->loadViewsFrom(realpath(__DIR__.'/Views'), 'DrpUserAdmin');

        $this->publishes([
            __DIR__.'/Migrations' => database_path('migrations')
        ], 'migrations');

        $this->publishes([
            __DIR__.'/Seeders' => database_path('seeds')
        ], 'seeds');

        if (config('drpadmin.useAdminRoutes') &&
            !$this->app->routesAreCached() ||
            config('drpadmin') == false
        ) {
            $baseRoutePath = config('drpadmin.baseRoutePath');
            require __DIR__ . '/Http/routes.php';
        }

        $router = $this->app->make('router');
        $router->middleware('admin-role', 'drp\AdminPanel\User\Middleware\RoleMiddleware');

        $sidebar = app('Sidebar');
        $sidebar->addMultiLevelItem(
            'fa-users',
            'Users',
            function () {
                $user = auth()->user();
                $roles = config('drpadmin.userCrudRoles');
                $roles = explode('|', $roles);
                foreach ($roles as $role) {
                    if ($user != null && $user->hasRole($role)) {
                        return true;
                    }
                }

                return false;
            },
            true
        )
        ->addItem('fa-list', 'All', route('admin.users.index', [], false))
        ->addItem('fa-pencil', 'Create', route('admin.users.create', [], false));
    }

    /**
     * Register any package services.
     *
     * @return void
     */
    public function register()
    {
    }
}
